Introduction
============

.. image:: https://badge.fury.io/py/wa_kat.png
    :target: https://pypi.python.org/pypi/wa_kat

.. image:: https://img.shields.io/pypi/dm/wa-kat.svg
    :target: https://pypi.python.org/pypi/wa_kat

.. image:: https://readthedocs.org/projects/wa-kat/badge/?version=latest
    :target: http://wa-kat.readthedocs.org/

.. image:: https://img.shields.io/pypi/l/wa-kat.svg

.. image:: https://img.shields.io/github/issues/WebArchivCZ/WA-KAT.svg
    :target: https://github.com/WebArchivCZ/WA-KAT/issues


Documentation
-------------

Module documentation and description can be found at Read the Docs:

- http://wa-kat.readthedocs.org

Demo
----

Demo of the project can be found here:

- http://forpsi.kitakitsune.org:8080/
